@@ -2,7 +2,6 @@
 # at port 8080 and with ENV=test
 # Example: python main.py  --env test --mode TCP --tcp_port 8080 --log-level INFO
 import json
-import os
 
 import pytest
 
@@ -11,12 +10,13 @@ from .. import SDK
 
 LOCALHOST = "127.0.0.1"
 SERVER_PORT = 8080
+LOG_LEVEL = "ERROR"
 TEST_TEKTRONIX_OSC_PHYSICAL_ADDRESS = "USB0::0x0699::0x0363::C107676::INSTR"
 TEST_TEKTRONIX_OSC_INSTRUMENT_ID = 1
 MOCK_CAMERA_ID = 2
 UNEXISTING_INSTRUMENT_ID = 999
 SOME_VALID_TEKTRONIX_OSC_COMMAND = "clear_status"
-SOME_VALID_TEKTRONIX_OSC_COMMAND_INVOCATION = "set_trigger_level 3.4"
+SOME_VALID_TEKTRONIX_OSC_COMMAND_INVOCATION = "clear_status"
 MOCK_IMAGE_PATH = "Open_LISA_SDK/tests/mock_img.jpg"
 
 VALID_INSTRUMENT_CREATION_DICT = {
@@ -33,7 +33,7 @@ VALID_INSTRUMENT_UPDATE_DICT = {
 
 
 def test_get_instruments_as_python_list_of_dicts():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     instruments = sdk.get_instruments(response_format="PYTHON")
     assert isinstance(instruments, list)
@@ -43,7 +43,7 @@ def test_get_instruments_as_python_list_of_dicts():
 
 
 def test_get_instruments_as_json_string():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     instruments_json_string = sdk.get_instruments(response_format="JSON")
     assert isinstance(instruments_json_string, str)
@@ -58,7 +58,7 @@ def test_get_instruments_as_json_string():
 
 
 def test_get_specific_instrument_as_python_dict():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     instrument = sdk.get_instrument(
         instrument_id=TEST_TEKTRONIX_OSC_INSTRUMENT_ID, response_format="PYTHON")
@@ -69,7 +69,7 @@ def test_get_specific_instrument_as_python_dict():
 
 
 def test_get_specific_instrument_as_json_str():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     instrument_json = sdk.get_instrument(
         instrument_id=TEST_TEKTRONIX_OSC_INSTRUMENT_ID, response_format="JSON")
@@ -80,7 +80,7 @@ def test_get_specific_instrument_as_json_str():
 
 
 def test_get_specific_instrument_that_does_not_exist_raises_exception():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
 
     with pytest.raises(OpenLISAException):
@@ -90,7 +90,7 @@ def test_get_specific_instrument_that_does_not_exist_raises_exception():
 
 
 def test_get_instrument_commands_as_python_list_of_dicts():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     commands = sdk.get_instrument_commands(
         instrument_id=TEST_TEKTRONIX_OSC_INSTRUMENT_ID, response_format="PYTHON")
@@ -100,7 +100,7 @@ def test_get_instrument_commands_as_python_list_of_dicts():
 
 
 def test_get_instrument_commands_as_json_string():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     commands_json_string = sdk.get_instrument_commands(
         instrument_id=TEST_TEKTRONIX_OSC_INSTRUMENT_ID, response_format="JSON")
@@ -110,7 +110,7 @@ def test_get_instrument_commands_as_json_string():
 
 
 def test_is_valid_command_invocation_with_a_valid_invocation_returns_true():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     is_valid = sdk.is_valid_command_invocation(
         instrument_id=TEST_TEKTRONIX_OSC_INSTRUMENT_ID,
@@ -120,7 +120,7 @@ def test_is_valid_command_invocation_with_a_valid_invocation_returns_true():
 
 
 def test_is_valid_command_invocation_with_invalid_invocations_returns_false():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     invalid_invocations = [
         "unexisting command",
@@ -137,7 +137,7 @@ def test_is_valid_command_invocation_with_invalid_invocations_returns_false():
 
 
 def test_send_command_to_get_image_from_mock_camera():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     result = sdk.send_command(instrument_id=MOCK_CAMERA_ID,
                               command_invocation="get_image")
@@ -145,21 +145,24 @@ def test_send_command_to_get_image_from_mock_camera():
         image_bytes = f.read()
         assert image_bytes == result["value"]
 
+
 def test_send_command_and_save_result_in_server():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     result = sdk.send_command(instrument_id=MOCK_CAMERA_ID,
                               command_invocation="get_image", command_result_output_file="sandbox/output.jpg")
     assert result == None
-    sandbox_dir = sdk.get_directory_structure("sandbox", response_format="PYTHON")
+    sandbox_dir = sdk.get_directory_structure(
+        "sandbox", response_format="PYTHON")
     # TODO: assert here that output.jpg exists in server
     sdk.delete_file(file_path="sandbox/output.jpg")
-    sandbox_dir = sdk.get_directory_structure("sandbox", response_format="PYTHON")
+    sandbox_dir = sdk.get_directory_structure(
+        "sandbox", response_format="PYTHON")
     # TODO: assert here that output.jpg does not exist in server
 
 
 def test_instrument_CRUDs():
-    sdk = SDK(log_level="ERROR")
+    sdk = SDK(log_level=LOG_LEVEL)
     sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
     new_instrument = sdk.create_instrument(
         new_instrument=VALID_INSTRUMENT_CREATION_DICT, response_format="PYTHON")
@@ -178,42 +181,3 @@ def test_instrument_CRUDs():
         sdk.get_instrument(instrument_id=deleted_instrument["id"])
 
     sdk.disconnect()
-
-def test_filesystem():
-    sdk = SDK(log_level="ERROR")
-    sdk.connect_through_TCP(host=LOCALHOST, port=SERVER_PORT)
-
-    # Get sandbox filesystem structure
-    expected_sandbox_structure = {} # TODO
-    result = sdk.get_directory_structure("sandbox", response_format="PYTHON") # NOTE: sandbox, clibs and database will be enums?
-    assert result == expected_sandbox_structure
-
-    # create new folder and assert that is created
-    sdk.create_directory("sandbox", "new_folder")
-    expected_sandbox_structure_with_new_folder = {} # TODO
-    result = sdk.get_directory_structure("sandbox", response_format="PYTHON")
-    assert result == expected_sandbox_structure_with_new_folder
-
-    # send file to new folder and get again from server with new name
-    mock_img_path =  os.path.join(os.path.dirname(__file__), "/mock_img.jpg")
-    target_file = "sandbox/new_folder/remote_img.jpg"
-    sdk.send_file(str(mock_img_path), file_target_name=target_file)
-    result = sdk.get_directory_structure("sandbox", response_format="PYTHON")
-    # TODO: assert that target_file exists in result
-    file_target_name = "img_from_server.jpg"
-    sdk.get_file(target_file, file_target_name=file_target_name)
-    # TODO: assert that file_target_name exists in os.path.dirname(__file__) and delete it
-    # TODO: assert that file bytes are the same with mock_img
-
-    sdk.delete_file(remote_file=target_file)
-    result = sdk.get_directory_structure("sandbox", response_format="PYTHON")
-    # TODO: assert that target_file does not exist in result
-
-    sdk.delete_directory(remote_path="sandbox/new_folder")
-    result = sdk.get_directory_structure("sandbox", response_format="PYTHON")
-    # TODO: assert that new_folder does not exist in result
-
-
-
-
-
